import { useState } from 'react'
import { useNavigate } from 'react-router-dom'

interface CreateChecklistProps {
  className?: string
}

export default function CreateChecklist({ className = '' }: CreateChecklistProps) {
  const [checklistName, setChecklistName] = useState('')
  const [isCreating, setIsCreating] = useState(false)
  const navigate = useNavigate()

  const createChecklist = async () => {
    if (!checklistName.trim()) return

    setIsCreating(true)
    try {
      const response = await fetch('/api/checklists', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ name: checklistName.trim() }),
      })

      if (response.ok) {
        const data = await response.json()

        // Navigate to the new checklist
        navigate(`/${data.uuid}`)
      } else {
        alert('Failed to create checklist')
      }
    } catch (error) {
      console.error('Error creating checklist:', error)
      alert('Failed to create checklist')
    } finally {
      setIsCreating(false)
      setChecklistName('')
    }
  }

  const handleKeyDown = (e: React.KeyboardEvent) => {
    if (e.key === 'Enter') {
      createChecklist()
    }
  }

  return (
    <div className={`bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700 p-8 ${className}`}>
      <h2 className="text-2xl font-bold text-gray-900 dark:text-white mb-6">Create New Checklist</h2>
      <div className="flex flex-col sm:flex-row gap-4">
        <input
          type="text"
          placeholder="Enter checklist name..."
          value={checklistName}
          onChange={(e) => setChecklistName(e.target.value)}
          onKeyDown={handleKeyDown}
          disabled={isCreating}
          className="flex-1 px-4 py-3 border border-gray-300 dark:border-gray-600 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent disabled:bg-gray-100 dark:disabled:bg-gray-700 disabled:text-gray-500 dark:disabled:text-gray-400 bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
        />
        <button 
          onClick={createChecklist} 
          disabled={isCreating || !checklistName.trim()}
          className="
            px-8 py-3 bg-blue-600 dark:bg-blue-500 text-white font-medium rounded-lg hover:bg-blue-700 dark:hover:bg-blue-600
            focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 disabled:opacity-50
            disabled:cursor-not-allowed transition-colors duration-200
          "
        >
          {isCreating ? 'Creating...' : 'Create'}
        </button>
      </div>
    </div>
  )
} 